OH_ImagePackerNative_PackToDataFromImageSource

Function OH_ImagePackerNative_PackToDataFromImageSource 

pub unsafe extern "C" fn OH_ImagePackerNative_PackToDataFromImageSource(
    imagePacker: *mut OH_ImagePackerNative,
    options: *mut OH_PackingOptions,
    imageSource: *mut OH_ImageSourceNative,
    outData: *mut u8,
    size: *mut usize,
) -> Image_ErrorCode
@brief Encoding an ImageSource into the data with required format.

@param imagePacker The imagePacker to use for packing. @param options Indicates the encoding {@link OH_PackingOptions}. @param imageSource The imageSource to be packed. @param outData The output data buffer to store the packed image. @param size A pointer to the size of the output data buffer. @return Image functions result code. {@link IMAGE_SUCCESS} if the execution is successful. {@link IMAGE_BAD_PARAMETER}imagePacker is nullptr, or options is nullptr, or imageSource is nullptr, or outData is nullptr. {@link IMAGE_ENCODE_FAILED} encode failed. @since 12