OH_ImagePackerNative_PackToFileFromImageSource

Function OH_ImagePackerNative_PackToFileFromImageSource 

pub unsafe extern "C" fn OH_ImagePackerNative_PackToFileFromImageSource(
    imagePacker: *mut OH_ImagePackerNative,
    options: *mut OH_PackingOptions,
    imageSource: *mut OH_ImageSourceNative,
    fd: i32,
) -> Image_ErrorCode
@brief Encoding an ImageSource into the a file with fd with required format.

@param imagePacker The image packer to use for packing. @param options Indicates the encoding {@link OH_PackingOptions}. @param imageSource The imageSource to be packed. @param fd Indicates a writable file descriptor. @return Image functions result code. {@link IMAGE_SUCCESS} if the execution is successful. {@link IMAGE_BAD_PARAMETER}imagePacker is nullptr, or options is nullptr, or imageSource is nullptr, or fd is invalid. {@link IMAGE_ENCODE_FAILED} encode failed. @since 12