pub unsafe extern "C" fn OH_ImageSourceNative_CreateFromData(
data: *mut u8,
dataSize: usize,
res: *mut *mut OH_ImageSourceNative,
) -> Image_ErrorCodeExpand description
@brief Creates an void pointer
@param data Indicates a pointer to the image source data. Only a formatted packet data or Base64 data is accepted. @param dataSize Indicates the size of the image source data. @param res Indicates a void pointer to the ImageSource object created at the C++ native layer. @return Returns one of the following result codes: {@link IMAGE_SUCCESS} if the execution is successful. {@link IMAGE_BAD_PARAMETER} if data is a null pointer or if dataSize is 0. @since 12