OH_ImageSourceNative_CreateFromUri

Function OH_ImageSourceNative_CreateFromUri 

pub unsafe extern "C" fn OH_ImageSourceNative_CreateFromUri(
    uri: *mut c_char,
    uriSize: usize,
    res: *mut *mut OH_ImageSourceNative,
) -> Image_ErrorCode
@brief Creates an ImageSource pointer.

@param uri Indicates a pointer to the image source URI. Only a file URI or Base64 URI is accepted. @param uriSize Indicates the length of the image source URI. @param res Indicates a pointer to the ImageSource object created at the C++ native layer. @return Returns one of the following result codes: {@link IMAGE_SUCCESS} if the execution is successful. {@link IMAGE_BAD_PARAMETER} if uri is a null pointer. @since 12