OH_ImageSourceNative_CreatePixelmap

Function OH_ImageSourceNative_CreatePixelmap 

pub unsafe extern "C" fn OH_ImageSourceNative_CreatePixelmap(
    source: *mut OH_ImageSourceNative,
    options: *mut OH_DecodingOptions,
    pixelmap: *mut *mut OH_PixelmapNative,
) -> Image_ErrorCode
@brief Decodes an void pointer based on the specified {@link OH_DecodingOptions} struct.

@param source Indicates a void pointer(from ImageSource pointer convert). @param options Indicates a pointer to the options for decoding the image source. For details, see {@link OH_DecodingOptions}. @param pixelmap Indicates a void pointer to the Pixelmap object obtained at the C++ native layer. @return Returns one of the following result codes: {@link IMAGE_SUCCESS} if the execution is successful. {@link IMAGE_BAD_PARAMETER} source is nullptr. {@link IMAGE_SOURCE_UNSUPPORTED_OPTIONS} unsupported options, e.g, cannot convert image into desired pixel format. @since 12