OH_ImageSourceNative_CreatePixelmapList

Function OH_ImageSourceNative_CreatePixelmapList 

pub unsafe extern "C" fn OH_ImageSourceNative_CreatePixelmapList(
    source: *mut OH_ImageSourceNative,
    options: *mut OH_DecodingOptions,
    resVecPixMap: *mut *mut OH_PixelmapNative,
    size: usize,
) -> Image_ErrorCode
@brief Decodes an void pointer the Pixelmap objects at the C++ native layer based on the specified {@link OH_DecodingOptions} struct.

@param source Indicates a void pointer(from ImageSource pointer convert). @param options Indicates a pointer to the options for decoding the image source. For details, see {@link OH_DecodingOptions}. @param resVecPixMap Indicates a pointer array to the Pixelmap objects obtained at the C++ native layer. It cannot be a null pointer. @param size Indicates a size of resVecPixMap. User can get size from {@link OH_ImageSourceNative_GetFrameCount}. @return @return Returns one of the following result codes: {@link IMAGE_SUCCESS} if the execution is successful. {@link IMAGE_BAD_PARAMETER} source is nullptr, or options is nullptr, or resVecPixMap is nullptr. @since 12