OH_ImageSourceNative_GetDelayTimeList

Function OH_ImageSourceNative_GetDelayTimeList 

pub unsafe extern "C" fn OH_ImageSourceNative_GetDelayTimeList(
    source: *mut OH_ImageSourceNative,
    delayTimeList: *mut i32,
    size: usize,
) -> Image_ErrorCode
@brief Obtains the delay time list from some ImageSource objects (such as GIF image sources).

@param source Indicates a void pointer(from ImageSource pointer convert). @param delayTimeList Indicates a pointer to the delay time list obtained. It cannot be a null pointer. @param size Indicates a size of delayTimeList. User can get size from {@link OH_ImageSourceNative_GetFrameCount}. @return Returns one of the following result codes: {@link IMAGE_SUCCESS} if the execution is successful. {@link IMAGE_BAD_PARAMETER} source is nullptr, or delayTimeList is nullptr. @since 12