OH_ImageSourceNative_GetFrameCount

Function OH_ImageSourceNative_GetFrameCount 

pub unsafe extern "C" fn OH_ImageSourceNative_GetFrameCount(
    source: *mut OH_ImageSourceNative,
    frameCount: *mut u32,
) -> Image_ErrorCode
@brief Obtains the number of frames from an ImageSource object.

@param source Indicates a pointer to the {@link OH_ImageSource} object at the C++ native layer. @param res Indicates a pointer to the number of frames obtained. @return Returns one of the following result codes: {@link IMAGE_SUCCESS} if the execution is successful. {@link IMAGE_BAD_PARAMETER} source is nullptr, or frameCount is nullptr. @since 12