OH_ImageSourceNative_GetImageInfo

Function OH_ImageSourceNative_GetImageInfo 

pub unsafe extern "C" fn OH_ImageSourceNative_GetImageInfo(
    source: *mut OH_ImageSourceNative,
    index: i32,
    info: *mut OH_ImageSource_Info,
) -> Image_ErrorCode
@brief Obtains image source information from an ImageSource object by index.

@param source Indicates a void pointer(from ImageSource pointer convert). @param index Indicates the index of the frame. @param info Indicates a pointer to the image source information obtained. For details, see {@link OH_ImageSource_Info}. @return Returns one of the following result codes: {@link IMAGE_SUCCESS} if the execution is successful. {@link IMAGE_BAD_PARAMETER} source is nullptr, or info is nullptr, or failed to get image info. @since 12