pub unsafe extern "C" fn OH_ImageSourceNative_ModifyImageProperty(
source: *mut OH_ImageSourceNative,
key: *mut Image_String,
value: *mut Image_String,
) -> Image_ErrorCodeExpand description
@brief Modifies the value of an image property of an ImageSource object. @param source Indicates a void pointer(from ImageSource pointer convert). @param key Indicates a pointer to the property. For details, see {@link Image_String}., key is an exif constant. Release after use ImageSource, see {@link OH_ImageSourceNative_Release}. @param value Indicates a pointer to the new value of the property. @return Returns one of the following result codes: {@link IMAGE_SUCCESS} if the execution is successful. {@link IMAGE_BAD_PARAMETER} source is nullptr, or key is nullptr, or value is nullptr, or failed to modify image property because of invalid parameters. @since 12