OH_PixelmapNative_ConvertAlphaFormat

Function OH_PixelmapNative_ConvertAlphaFormat 

pub unsafe extern "C" fn OH_PixelmapNative_ConvertAlphaFormat(
    srcpixelmap: *mut OH_PixelmapNative,
    dstpixelmap: *mut OH_PixelmapNative,
    isPremul: bool,
) -> Image_ErrorCode
@brief Converting images to alpha format

@param srcpixelmap The source pixel map pointer will be operated. @param dstpixelmap The destination pixel map pointer will be operated. @param isPremul Whether it is pre-multiplied, true for prediction, false for non-pre-multiplied. @return Function result code: {@link IMAGE_SUCCESS} - if the operation is successful. {@link IMAGE_BAD_PARAMETER} - if either: 1.srcpixelmap or dstpixelmap is null pointer. 2.Their inner pixelmap structures are unavailable. @since 12