pub unsafe extern "C" fn OH_PixelmapNative_CreateEmptyPixelmap(
options: *mut OH_Pixelmap_InitializationOptions,
pixelmap: *mut *mut OH_PixelmapNative,
) -> Image_ErrorCodeExpand description
@brief Create a empty PixelMap object.
@param options IPixel properties, including the alpha type, size, pixel format, and editable. @param pixelmap Pixelmap pointer for created. @return Function result code: {@link IMAGE_SUCCESS} - if the operation is successful. {@link IMAGE_BAD_PARAMETER} - if options is null or failed to create pixelmap due to invalid options. @since 12