OH_PixelmapNative_CreatePixelmap

Function OH_PixelmapNative_CreatePixelmap 

pub unsafe extern "C" fn OH_PixelmapNative_CreatePixelmap(
    data: *mut u8,
    dataLength: usize,
    options: *mut OH_Pixelmap_InitializationOptions,
    pixelmap: *mut *mut OH_PixelmapNative,
) -> Image_ErrorCode
@brief Creates a PixelMap object.

@param data Color buffer in BGRA_8888 format. @param dataLength Color buffer size in BGRA_8888 format. @param options IPixel properties, including the alpha type, size, pixel format, and editable. @param pixelmap Pixelmap pointer for created. @return Function result code: {@link IMAGE_SUCCESS} - if the operation is successful. {@link IMAGE_BAD_PARAMETER} - Possible causes: if data or options is null or failed to create pixelmap due to invalid options. @since 12