OH_PixelmapNative_WritePixels

Function OH_PixelmapNative_WritePixels 

pub unsafe extern "C" fn OH_PixelmapNative_WritePixels(
    pixelmap: *mut OH_PixelmapNative,
    source: *mut u8,
    bufferSize: usize,
) -> Image_ErrorCode
@brief Reads image data in an Buffer and writes the data to a Pixelmap object.

@param pixelmap The Pixelmap pointer will be operated. @param source Buffer from which the image data will be read. @param bufferSize Buffer size from which the image data will be read. @return Function result code: {@link IMAGE_SUCCESS} if the execution is successful. {@link IMAGE_BAD_PARAMETER} Parameter error. Possible causes: 1.Parameter is nullptr 2.pixelmap’s inner pixelmap is nullptr. 3.Parameter bufferSize is less than the actual data size. {@link IMAGE_UNSUPPORTED_OPERATION} If the pixelmap is not editable. {@link IMAGE_UNKNOWN_ERROR} Internal unknown error, e.g. memory copy failed or pixelmap’s attributes are incorrect. @since 12