pub unsafe extern "C" fn OH_ImageSourceNative_GetImageProperty(
source: *mut OH_ImageSourceNative,
key: *mut Image_String,
value: *mut Image_String,
) -> Image_ErrorCodeExpand description
@brief Obtains the value of an image property from an ImageSource object.
@param source Pointer to ImageSource. @param key Pointer to the property key. @param value Pointer to the property value. Output Parameter. @return Returns one of the following result codes: {@link IMAGE_SUCCESS} if the execution is successful. {@link IMAGE_BAD_PARAMETER} source is nullptr, or key is nullptr, or value is nullptr. {@link IMAGE_ALLOC_FAILED} allocate memory failed. {@link IMAGE_COPY_FAILED} copy memory failed. @since 12